@@ -1,5 +1,5 @@
-from qtools.qtpy.QtCore import Qt 
-from qtools.qtpy import QtGui, QT_BINDING, QT_BINDING_VERSION
+from qtop.qtpy.QtCore import Qt 
+from qtop.qtpy import QtGui, QT_BINDING, QT_BINDING_VERSION
 import os
 
 __all__ = ['get_cursor']
